@@ -3,35 +3,32 @@
 # for quick tests only, should not be depended upon for
 # proper examples of current api.
 
-use Mojo::Base -strict;
+use strict;
+use warnings;
 use FindBin;
 use lib "$FindBin::Bin/../../lib";
 use Net::Launchpad::Client;
+use Net::Launchpad::Model;
 use List::AllUtils qw(first);
-
-use DDP;
+use Data::Dumper::Concise;
 
 my $public_bug = $ENV{LP_BUG} || '1268207';
 
-my $c = Net::Launchpad::Client->new;
-if (   defined($ENV{LP_CONSUMER_KEY})
-    && defined($ENV{LP_ACCESS_TOKEN})
-    && defined($ENV{LP_ACCESS_TOKEN_SECRET}))
-{
-    $c->consumer_key($ENV{LP_CONSUMER_KEY});
-    $c->access_token($ENV{LP_ACCESS_TOKEN});
-    $c->access_token_secret($ENV{LP_ACCESS_TOKEN_SECRET});
-}
+my $lpc = Net::Launchpad::Client->new(
+    consumer_key        => $ENV{LP_CONSUMER_KEY},
+    access_token        => $ENV{LP_ACCESS_TOKEN},
+    access_token_secret => $ENV{LP_ACCESS_TOKEN_SECRET}
+);
 
-# Set whether we want staging or not
-$c->staging(0);
+my $model = Net::Launchpad::Model->new(lpc => $lpc);
 
-p $c;
-my $bug = $c->model('Bug')->by_id($public_bug);
+my $bug = $model->bug($public_bug);
+my $tasks = $bug->tasks;
 
-say "Bug representation";
+my $branch = $model->branch('~adam-stokes', '+junk', 'cloud-installer');
+#print Dumper($branch->dependent_branches);
 
-p $bug->title;
+#p $bug_item;
 # p $bug->tasks;
 # p $bug->date_created;
 # p $bug->watches;
